@@ -14,11 +14,6 @@ import string
 
 import ldap
 
-import sys
-
-sys.setrecursionlimit(10**6)
-
-
 __all__ = ["Position", "Department", "SystemAccount", "User", "App", "AppGroup"]
 
 
